.. currentmodule:: gorilla

.. _reference:

API Reference
=============

The whole public interface of Gorilla is described here.

All of the library's content is accessible from within the only module
``gorilla``.

The classes :class:`Settings`, :class:`Patch`, and the function `apply` form
the :ref:`core <core>` of the library and cover all the requirements for monkey
patching.

For intuitivity and convenience reasons, :ref:`decorators <decorators>` and
:ref:`utility <utilities>` functions are also provided.

.. toctree::
   :maxdepth: 2

   core
   decorators
   utilities
